texture g_texturea;
texture g_textureb;

sampler2D g_samSrcColor =
sampler_state
{
    Texture = <g_texturea>;
};


sampler2D g_samFullScreen =
sampler_state
{
    Texture = <g_textureb>;
};

float BulletTime=1.0f;
float ScreenMoveX=0.0f;
float ScreenMoveY=0.0f;

float bloom_threshold = 0.5f;
float bloom_multiply = 5.0f;
float PixelSize = 0.001f;
float bloom_blursize = 1.0;
float bloom_colour = 0.5;


// all these are stolen from the DirectX SDK - sorry Bill, hope you don't mind!
static const int g_cKernelSize = 13;


static const float BlurWeights[g_cKernelSize] = 
{
    0.002216,
    0.008764,
    0.026995,
    0.064759,
    0.120985,
    0.176033,
    0.199471,
    0.176033,
    0.120985,
    0.064759,
    0.026995,
    0.008764,
    0.002216,
};


float2 PixelCoordsDownFilter[16] =
{
    { 1.5,  -1.5 },
    { 1.5,  -0.5 },
    { 1.5,   0.5 },
    { 1.5,   1.5 },

    { 0.5,  -1.5 },
    { 0.5,  -0.5 },
    { 0.5,   0.5 },
    { 0.5,   1.5 },

    {-0.5,  -1.5 },
    {-0.5,  -0.5 },
    {-0.5,   0.5 },
    {-0.5,   1.5 },

    {-1.5,  -1.5 },
    {-1.5,  -0.5 },
    {-1.5,   0.5 },
    {-1.5,   1.5 },
};

float BloomScale = 1.5f;


float4 DownSize( float2 Tex : TEXCOORD0 ) : COLOR0
{
    float4 Color=0;
       
    for (int i = 0; i < 16; i++)
    {
        Color += tex2D( g_samFullScreen, Tex + (PixelCoordsDownFilter[i].xy*PixelSize) + (PixelSize*2.0f) );
    }
    
    Color = Color / 16.0f;

          
    return Color;
}


float4 FadeColour( float2 Tex : TEXCOORD0 ) : COLOR0
{
    float4 Color;
    
    Color = tex2D( g_samSrcColor, Tex);
    
    Color = Color - bloom_threshold;
    Color = Color * bloom_multiply;
    
    Color.r = (((Color.r+Color.g+Color.b)/3.0f)*(1.0f-bloom_colour)) + (Color.r*bloom_colour);
    Color.g = (((Color.r+Color.g+Color.b)/3.0f)*(1.0f-bloom_colour)) + (Color.g*bloom_colour);
    Color.b = (((Color.r+Color.g+Color.b)/3.0f)*(1.0f-bloom_colour)) + (Color.b*bloom_colour);
    
    Color.a = 1.0f;
       
    return Color;
}



float4 HBlur( float2 Tex : TEXCOORD0 ) : COLOR0
{
    float4 Color=0;
    
    for (int i = -6; i < 6; i++)
    {    
        Color += tex2D( g_samSrcColor, Tex + (float2(i*bloom_blursize*PixelSize,0.0))) * BlurWeights[i+6];
    }
    


	Color.a = 1.0f;
    return Color*1.5;
}


float4 VBlur( float2 Tex : TEXCOORD0 ) : COLOR0
{
    float4 Color=0;
    
    for (int i = -6; i < 6; i++)
    {    
        Color += tex2D( g_samSrcColor, Tex + (float2(0.0,i*bloom_blursize*PixelSize))) * BlurWeights[i+6];
    }



	Color.a = 1.0f;
    return Color*1.5;
}

technique One
{
    pass p0
    {
        VertexShader = null;
        PixelShader = compile ps_2_0 DownSize();
    }
    
    pass p1
    {
        VertexShader = null;
        PixelShader = compile ps_2_0 FadeColour();
    }
    
    pass p2
    {
        VertexShader = null;
        PixelShader = compile ps_2_0 HBlur();
    }
    pass p3
    {
        VertexShader = null;
        PixelShader = compile ps_2_0 VBlur();
    }
    


}
